@@ -275,9 +275,13 @@ def get_scope_of_host_ids_from_host_list():
     else:
         etld_lib_functions.logger.error(f"error vm_processed_after: {etld_lib_config.host_list_detection_vm_processed_after} ")
         exit(1)
-
+    #
+    #  f"WHERE LAST_VM_SCANNED_DATE > datetime('{vm_processed_after}') "
+    #  Qualys has internal algorithm for vm_processed_after.  Trust host list to pull all vm_processed after
+    #  and select all assets where LAST_VM_SCANNED_DATE is not "" or NULL.
+    #
     sql_statement = f"SELECT t.ID, t.LAST_VM_SCANNED_DATE FROM Q_Host_List t " \
-                    f"WHERE LAST_VM_SCANNED_DATE > datetime('{vm_processed_after}') " \
+                    f'WHERE LAST_VM_SCANNED_DATE is not "" or NULL ' \
                     f"ORDER BY LAST_VULN_SCAN_DATETIME DESC limit {host_list_detection_limit_hosts}"
 
     host_list_get_scope_of_host_ids_sql = sql_statement
